@@ -41,7 +41,7 @@ package Attean::SimpleQueryEvaluator 0.023 {
 	use LWP::UserAgent;
 	use Scalar::Util qw(blessed);
 	use List::Util qw(all any reduce);
-	use Types::Standard qw(ConsumerOf InstanceOf);
+	use Types::Standard qw(ConsumerOf InstanceOf Bool);
 	use URI::Escape;
 	use namespace::clean;
 
@@ -65,6 +65,8 @@ features such as C<< GRAPH ?g {} >>.
 
 	has 'user_agent' => (is => 'rw', isa => InstanceOf['LWP::UserAgent'], default => sub { my $ua = LWP::UserAgent->new(); $ua->agent("Attean/$Attean::VERSION " . $ua->_agent); $ua });
 	
+	has 'ground_blanks' => (is => 'rw', isa => Bool, default => 0);
+	
 =back
 
 =head1 METHODS
@@ -105,7 +107,7 @@ supplied C<< $active_graph >>.
 					my $q		= $t->as_quad_pattern($active_graph);
 					my @values;
 					foreach my $v ($q->values) {
-						if ($v->does('Attean::API::Blank')) {
+						if (not($self->ground_blanks) and $v->does('Attean::API::Blank')) {
 							unless (exists $blanks{$v->value}) {
 								$blanks{$v->value}	= Attean::Variable->new();
 								push(@new_vars, $blanks{$v->value}->value);
