@@ -7,7 +7,7 @@ AtteanX::API::Lexer - Role defining common functionality for lexers.
 
 =head1 VERSION
 
-This document describes AtteanX::API::Lexer version 0.017
+This document describes AtteanX::API::Lexer version 0.023
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ of characters, constant strings, and fixed-length buffers.
 
 =cut
 
-package AtteanX::API::Lexer 0.017 {
+package AtteanX::API::Lexer 0.023 {
 	use strict;
 	use Types::Standard qw(FileHandle Ref Str Int ArrayRef HashRef ConsumerOf InstanceOf);
 
@@ -173,7 +173,9 @@ Consume and return C<< $length >> characters  from the start of the buffer.
 		my $self	= shift;
 		my $len		= shift;
 		while (length($self->{buffer}) < $len) {
+			my $curlen	= length($self->{buffer});
 			$self->fill_buffer;
+			last if (length($self->{buffer}) == $curlen);
 		}
 	
 		my $word	= substr($self->{buffer}, 0, $len, '');
@@ -203,7 +205,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -211,7 +213,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2019 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
